#
# spec file for package uftpd
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2018-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uftpd
Version:        2.15
Release:        1.10
Summary:        A combined TFTP/FTP server
License:        ISC
Group:          Productivity/Networking/Ftp/Servers
URL:            https://troglobit.com/uftpd.html
#Git-Clone:     https://github.com/troglobit/uftpd.git
Source:         https://github.com/troglobit/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libite)
BuildRequires:  pkgconfig(libuev) >= 2.2.0
Conflicts:      atftp
Conflicts:      tftp
Provides:       tftp(server)
# SECTION test requirements
BuildRequires:  ftp
BuildRequires:  netcfg libnss_usrfiles2
BuildRequires:  tftp
# /SECTION

%description
uftpd serves both TFTP and FTP without any configuration file, starts
automatically from the traditional UNIX inetd super server, and is
tcpwrapped.

%prep
%setup -q

%build
autoreconf -fiv
%configure
%make_build

%install
%make_install
rm -rf %{buildroot}/%{_datadir}/doc

%check
# temporary run checks only on x86_64 until the issues on the other platforms are sorted out
%ifarch x86_64
ulimit -n 1024
make check || find . -name test-suite.log -exec cat {} +
%endif

%files
%doc README.md
%license LICENSE
%{_sbindir}/in.ftpd
%{_sbindir}/in.tftpd
%{_sbindir}/uftpd
%{_mandir}/man8/in.ftpd.8%{?ext_man}
%{_mandir}/man8/in.tftpd.8%{?ext_man}
%{_mandir}/man8/uftpd.8%{?ext_man}

%changelog
* Mon Dec 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.15
  Changes
  * Silence some developer debug messages
  * Always skip . and .. in FTP listings
  * Internal refactoring and code cleanup
  Fixes
  * Fix regression introduced in v2.14, server directory name shown
    in FTP
  * listings instead of ., e.g. MLST . showed the directory name
  * Fix #36: for real this time, now also with a test case to verify
  * Fix #38: duplicate entries in FTP listings, regression in v2.14
    Caused by (initially unintentional) removal of sorted listings,
    where directories prior to v2.14 were listed first. This change,
    albeit an accident, actually helped clean up the code base and
    speed up replies
* Sat Dec 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.14
  * Add support for -o pasv_addr=ADDR command line argument to
    override
  * Add support for -p PIDFILE command line argument
  * the address passed to the client in passive mode, useful for
    some types of NAT setup
* Mon Oct  4 2021 Martin Hauke <mardnh@gmx.de>
- Run testsuite only on x86_64
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.13
  Changes
  * Unit test framework in place, with regression test for issue
  Fixes
  * Socket leak in daemon accept() handling causing "Too many open
    files". Effectively causing denial of service
  * Minor memory leak fixed, only allocated once at startup.
    Affects only non-MMU systems
- Run testsuite
* Mon May 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.12
  Changes
  * Use common log message format and log level when user enters
    an invalid path. This unfortunately affects changes introduced
    in v2.11 to increase logging at default log level.
  * Fixes
    Issue #30: When entering an invalid directory with the FTP
    command CWD, a NULL ptr was deref. in a DBG() message even
    though the log level is set to a value lower than LOG_DEBUG.
    This caused uftpd to crash and cause denial of service.
    Depending on the init/inetd system used this could be
    permanent.
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11
  * Increased logging at default log level. Now all relevant
    interaction is logged. See the man page for how to adjust.
  * Fix buffer overflow in FTP PORT parser
  * Fix TFTP/FTP directory traversal regression
  * Fix potential DOS through non-busy loop and segfault
  * Fix potential segfault through empty FTP password
  * Fix potential segfault through FTP PORT command
* Mon Aug 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10
  * Add support for TFTP WRQ, i.e. for clients sending files to
    server
  * Fix invalid TFTP error codes, now uses custom error string to
    code 0
  * Slightly improved debug messages
* Mon Jul 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9
  * Check FTP root security after dropping privileges
  * Revert insecure default: "writable FTP root", introduced in v2.8
  * Revert part of issue #18 to fix issue #23; "CWD /" doesn't work
  * Fix spelling errors found by Lintian
  * Fix package description, more formal and less personal
* Tue May 28 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8
  Changes:
  * The FTP command processor now always converts all inbound
    commands to uppercase to handle clients sending commands in
    lowercase
  * Any arguments to the FTP LIST command are now ignored
  * Improved user feedback on bad FTP root error message
  Fixes
  * Fix #18: KDE Dolphin, FTP client interop problems.
  * Fix off-by-one regression introduced in v2.5
* Sun Mar  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7
  Changes
  * Documentation updates, commands added in v2.5 and writable opt
  * Require libuEv v2.2, or later
  Fixes
  * Issues with relative FTP root when running unpriviliged
* Fri Jul 27 2018 jengelh@inai.de
- Remove rhetoric filler wording from descriptions.
* Wed Jul  4 2018 mardnh@gmx.de
- Update to version 2.6
  Fixes
  * Issue #16: 100%% CPU when client session exits
  * Add missing include file for `gettimeofday()`
  * Flush stdout logging when running in the foreground
* Thu Jun 28 2018 mardnh@gmx.de
- Add Conflicts to not interfere with other packages that also
  provide /usr/sbin/in.tftpd
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 2.5
